==> coregarage-2.7.0.tar.gz: coregarage-v2.7.0/coregarage.h <==
/*
    *
    * This file is a part of CoreGarage.
    * A setting manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#ifndef COREGARAGE_H
#define COREGARAGE_H

#include <QWidget>
#include <QListWidgetItem>
#include <QToolButton>
#include <QButtonGroup>

#include <cprime/cvariables.h>
#include <cprime/desktopfile.h>
#include <cprime/settingsmanage.h>

class QPushButton;

namespace Ui {
    class coregarage;
}

class coregarage : public QWidget {
    Q_OBJECT

public:
    explicit coregarage(QWidget *parent = nullptr);
    ~coregarage();

private slots:
    void on_cancel_clicked();
    void on_ok_clicked();
    void on_browseF_clicked();
    void on_browseS_clicked();
    void pageClick(QToolButton *btn, int i, QString title);
    void on_coreapps_clicked();
    void on_coreaction_clicked();
    void on_backUp_clicked();
    void on_restore_clicked();
    void on_setTerminals_clicked();
    void on_setFileManger_clicked();
    void on_setImageEditor_clicked();
    void showBackupMessage();
    void showRestoreMessage();
    void on_coreterminal_clicked();
    void addRemoveApp(int);
    void on_appTitle_clicked();
    void on_addPluginPath_clicked();
    void on_delPluginPath_clicked();
    void on_pluginPaths_itemSelectionChanged();
    void on_availableWidgitsList_itemSelectionChanged();
    void on_selectedWidgetsList_itemSelectionChanged();
    void on_addPlugin_clicked();
    void on_removePlugin_clicked();
    void on_setMetadataViewer_clicked();
    void on_setSearchApp_clicked();
    void on_movePluginUp_clicked();
    void on_movePluginDown_clicked();
    void on_textViewFont_clicked();
    void on_terminalFont_clicked();
    void on_corekeyboard_clicked();
    void on_others_clicked();
    void on_setBG_clicked();
    void on_desktopMode_clicked(bool checked);
    void on_experimentalFeatures_clicked(bool checked);

private:
    Ui::coregarage *ui;
    settingsManage *sm = settingsManage::initialize(true);
    bool            sideView, touch;
    int             sideViewSize;
    QSize           sideViewIconSize, listViewIconSize;
    QStringList     m_selectedPlugins;
    QStringList     m_pluginsFolders;
    QString         m_defaultPluginPath = "/usr/lib/coreapps/plugins";
    QButtonGroup   *favAppsGrp;

    void searchPlugin(QListWidgetItem *item);
    void setupCoreAppsPage();
    void setupCoreActionPage();
    void setupCoreTerminalPage();
    void setupCoreKeyBoardPage();
    void loadSettings();
    void startSetup();
    void saveSettings();
    void setupOthersPage();
};

#endif // COREGARAGE_H

==> coregarage-2.8.0.tar.gz: coregarage-v2.8.0/coregarage.h <==
/*
    *
    * This file is a part of CoreGarage.
    * A setting manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#ifndef COREGARAGE_H
#define COREGARAGE_H

#include <QWidget>
#include <QListWidgetItem>
#include <QToolButton>
#include <QButtonGroup>

#include <cprime/cvariables.h>
#include <cprime/corexdg.h>
#include <cprime/settingsmanage.h>

class QPushButton;

namespace Ui {
    class coregarage;
}


class TaskItem : public QWidget {
    Q_OBJECT

public:
    explicit TaskItem(QString title, QIcon icon, QListWidgetItem *container, QWidget *parent = nullptr);
    ~TaskItem() {}

    QString getTitle();
    QIcon getIcon();
    quint64 getWinID();
    QListWidgetItem *getContainer();

signals:
    void closeOccured(QListWidgetItem *);

private:
    QIcon m_icon;
    QString m_title;
    quint64 m_winID;
    QListWidgetItem *m_container;
};

class coregarage : public QWidget {
    Q_OBJECT

public:
    explicit coregarage(QWidget *parent = nullptr);
    ~coregarage();

private slots:
    void on_cancel_clicked();
    void on_ok_clicked();
    void on_browseF_clicked();
    void on_browseS_clicked();
    void pageClick(QToolButton *btn, int i, QString title);
    void on_coreapps_clicked();
    void on_coreaction_clicked();
    void on_corestuff_clicked();
    void on_backUp_clicked();
    void on_restore_clicked();
    void on_setTerminals_clicked();
    void on_setFileManger_clicked();
    void on_setImageEditor_clicked();
    void showBackupMessage();
    void showRestoreMessage();
    void on_coreterminal_clicked();
    void addRemoveApp(int);
    void on_appTitle_clicked();
    void on_addPluginPath_clicked();
    void on_delPluginPath_clicked();
    void on_pluginPaths_itemSelectionChanged();
    void on_availableWidgitsList_itemSelectionChanged();
    void on_selectedWidgetsList_itemSelectionChanged();
    void on_addPlugin_clicked();
    void on_removePlugin_clicked();
    void on_setMetadataViewer_clicked();
    void on_setSearchApp_clicked();
    void on_movePluginUp_clicked();
    void on_movePluginDown_clicked();
    void on_textViewFont_clicked();
    void on_terminalFont_clicked();
    void on_others_clicked();
    void on_setBG_clicked();
    void on_desktopMode_clicked(bool checked);
    void on_restoreDefault_clicked();
    void on_newNSA_clicked();
    void on_setRenamerApp_clicked();
    void on_setArchiver_clicked();


    void on_help_clicked();

private:
    Ui::coregarage *ui;
    settingsManage *sm = settingsManage::initialize(false);
    bool            sideView, touch;
    int             sideViewSize;
    QSize           sideViewIconSize;
    QStringList     m_selectedPlugins;
    QStringList     m_pluginsFolders;
    QString         m_defaultPluginPath = "/usr/lib/coreapps/plugins";
    QButtonGroup   *favAppsGrp;

    void initialize();
    void searchPlugin(QListWidgetItem *item);
    void setupCoreAppsPage();
    void setupCoreActionPage();
    void setupCoreTerminalPage();
    void setupCoreStuffPage();
    void loadSettings();
    void startSetup();
    void saveSettings();
    void setupOthersPage();
    void removeStartUpApp(QListWidgetItem *container);
};

#endif // COREGARAGE_H
